Learn R Programming

ncappc (version 0.1)

ncappc: Performs NCA calculations and population PK model diagnosis.

Description

ncappc is a flexible tool, to
  1. perform a traditional NCA
  2. perform simulation-based posterior predictive checks for a population PK model using NCA metrics.

Usage

ncappc(obsFile = NULL, simFile = NULL, grNm = NULL, grp = NULL,
  flNm = NULL, flag = NULL, doseNm = NULL, dose = NULL,
  concUnit = NULL, timeUnit = NULL, doseUnit = NULL,
  doseNormUnit = NULL, obsLog = "FALSE", simLog = "FALSE",
  psnOut = "FALSE", idNmObs = "ID", timeNmObs = "TIME",
  concNmObs = "DV", idNmSim = "ID", timeNmSim = "TIME",
  concNmSim = "DV", AUCTimeRange = NULL, backExtrp = "FALSE",
  LambdaTimeRange = NULL, LambdaExclude = NULL,
  adminType = "extravascular", doseType = "ns", Tau = NULL, TI = NULL,
  doseAmtNm = NULL, doseAmt = NULL, method = "linear", blqNm = NULL,
  blqExcl = 1, evid = "FALSE", evidIncl = 0, mdv = "FALSE",
  filterNm = NULL, filterExcl = NULL, negConcExcl = "FALSE",
  param = c("AUClast", "Cmax"), timeFormat = "number", dateColNm = NULL,
  dateFormat = NULL, spread = "pi", tabCol = c("AUClast", "Cmax", "Tmax",
  "AUCINF_obs", "Vz_obs", "Cl_obs", "HL_Lambda_z"), printOut = "TRUE",
  figFormat = "tiff")

Arguments

obsFile
Observed concentration-time data from an internal data frame or an external table with comma, tab or space as separator
simFile
NONMEM simulation output with the simulated concentration-time data from an internal data frame or an external table ("NULL")
grNm
Column name for population stratifier ("NULL")
grp
Stratification ID (e.g c(1,2)) ("NULL")
flNm
Column name for popualtion stratifier ("NULL")
flag
Stratification ID (e.g. c(1,2)) ("NULL")
doseNm
Column name to specify dose identifiers ("NULL")
dose
Dose identifiers to be used (c(1,2)) ("NULL")
concUnit
Unit of concentration ("ng/mL") ("[M].[L]^-3")
timeUnit
Unit of time ("h") ("[T])
doseUnit
Unit of dose amount ("ng") ("[M]")
doseNormUnit
Normalization factor of dose amount if used (kg) ("NULL")
obsLog
Concentration in observed data in logarithmic form (TRUE, FALSE) ("FALSE")
simLog
Concentration in simulated data in logarithmic form (TRUE, FALSE) ("FALSE")
psnOut
observed data is an output from PsN or in NONMEM output format (TRUE, FALSE) ("FALSE")
idNmObs
Column name for ID in observed data ("ID")
timeNmObs
Column name for time in observed data ("TIME")
concNmObs
Column name for concentration in observed data ("DV")
idNmSim
Column name for ID in simulated data ("ID")
timeNmSim
Column name for time in simulated data ("TIME")
concNmSim
Column name for concentration in simulated data ("DV")
AUCTimeRange
User-defined window of time used to estimate AUC ("NULL")
backExtrp
If back-extrapolation is needed for AUC (TRUE or FALSE) ("FALSE")
LambdaTimeRange
User-defined window of time to estimate elimination rate-constant ("NULL")
LambdaExclude
User-defined excluded observations during estimation of elimination rate-constant ("NULL")
adminType
Route of administration (iv-bolus,iv-infusion,ss,extravascular) ("extravascular")
doseType
Steady-state (ss) or nonsteady-state (ns) dose ("ns")
Tau
Dosing interval for steady-state data ("NULL")
TI
Infusion duration ("NULL")
doseAmtNm
Column name to specify dose amount ("NULL")
doseAmt
Dose amounts ("NULL")
method
linear, loglinear or mixed ("linear")
blqNm
Name of BLQ column if used ("NULL")
blqExcl
Excluded BLQ value or logical condition (e.g. 1 or ">=1" or c(1,">3")) ("1")
evid
Use EVID (TRUE, FALSE) ("FALSE")
evidIncl
Included EVID ("0")
mdv
Use MDV (TRUE(includes data for MDV==0), FALSE) ("FALSE")
filterNm
Column name for filter ("NULL")
filterExcl
Filter identifier or logical condition used for row exclusion (e.g. c(1,2,"<20",">=100","!=100") ) ("NULL")
negConcExcl
Exclude -ve conc ("FALSE")
param
NCA parameters (AUClast, AUClower_upper, AUCINF_obs, AUCINF_pred, AUMClast, Cmax, Tmax, HL_Lambda_z) (c("AUClast", "Cmax"))
timeFormat
time format (number, H:M, H:M:S) ("number")
dateColNm
colunm name for date if used (Date, DATE) ("NULL")
dateFormat
date format (D-M-Y, D/M/Y or any other combination of D,M,Y) ("NULL")
spread
Measure of the spread of simulated data (sd or pi (95% nonparametric prediction interval)) ("pi")
tabCol
Output columns to be printed in the report in addition to ID, dose and population strata information (list of NCA metrics in a string array) (c("AUClast", "Cmax", "Tmax", "AUCINF_obs", "Vz_obs", "Cl_obs", "HL_Lambda_z"))
printOut
Write/print output on the disk (TRUE, FALSE) ("TRUE")
figFormat
format of the produced figures (bmp, jpeg, tiff, png) ("tiff")

Value

  • NCA results and diagnostic test results

Details

Non-compartmental analysis (NCA) calculates pharmacokinetic (PK) metrics related to the systemic exposure to a drug following administration, e.g. area under the concentration-time curve and peak concentration. ncappc performs a traditional NCA using the observed plasma concentration-time data. In the presence of simulated plasma concentration-time data, ncappc also performs simulation-based posterior predictive checks (ppc) using NCA metrics for the corresponding population PK (PopPK) model used to generate the simulated data. The diagnostic analysis is performed at the population as well as the individual level. The distribution of the simulated population means of each NCA metric is compared with the corresponding observed population mean. The individual level comparison is performed based on the deviation of the mean of any NCA metric based on simulations for an individual from the corresponding NCA metric obtained from the observed data. Additionaly, ncappc reports the normalized prediction distribution error (NPDE) of the simulated NCA metrics for each individual and their distribution within a population. ncappc produces two default outputs depending on the type of analysis performed, i.e., traditional NCA and PopPK diagnosis. The PopPK diagnosis feature of ncappc produces 7 sets of graphical outputs to assess the ability of a population model to simulate the concentration-time profile of a drug and thereby identify model misspecification. In addition, tabular outputs are generated showing the values of the NCA metrics estimated from the observed and the simulated data, along with the deviation, NPDE, regression parameters used to estimate the elimination rate constant and the related population statistics. The default values of the arguments used in ncappc are shown in bold.